@@ -40,11 +40,11 @@ target[target == 0] = -1
 net = nl.net.newhop(target)
 
 output = net.sim(target)
-print "Test on train samples:"
+print("Test on train samples:")
 for i in range(len(target)):
-    print chars[i], (output[i] == target[i]).all()
+    print(chars[i], (output[i] == target[i]).all())
 
-print "\nTest on defaced N:"
+print("\nTest on defaced N:")
 test =np.asfarray([0,0,0,0,0,
                    1,1,0,0,1,
                    1,1,0,0,1,
@@ -52,4 +52,4 @@ test =np.asfarray([0,0,0,0,0,
                    0,0,0,1,1])
 test[test==0] = -1
 out = net.sim([test])
-print (out[0] == target[0]).all(), 'Sim. steps',len(net.layers[0].outs)
+print ((out[0] == target[0]).all(), 'Sim. steps',len(net.layers[0].outs))
