@@ -32,13 +32,14 @@ Delta rule
 """
 
 from . import gd, spo, wta, lvq, delta
+import functools
 
 def trainer(Train):
     """ Trainner init """
     from neurolab.core import Trainer
-    
-    c = Trainer(Train)
-    c.__doc__ = Train.__doc__
+    w = functools.wraps(Train)
+    c = w(Trainer(Train))
+    #c.__doc__ = Train.__doc__
     return c
 
 # Initializing mains train functors
@@ -57,4 +58,4 @@ train_ncg = trainer(spo.TrainNCG)
 train_wta = trainer(wta.TrainWTA)
 train_cwta = trainer(wta.TrainCWTA)
 train_lvq = trainer(lvq.TrainLVQ)
-train_delta = trainer(delta.TrainDelta)
\ No newline at end of file
+train_delta = trainer(delta.TrainDelta)
